package cn.pluss.platform.activityRecharge;

import java.util.List;
import java.util.Map;
import cn.pluss.platform.entity.ActivityRecharge;
import com.baomidou.mybatisplus.extension.service.IService;

/**
 * @author DJH
 */
public interface ActivityRechargeService extends IService<ActivityRecharge> {

    ActivityRecharge queryActivityRecharge(ActivityRecharge activityRecharge);

    List<ActivityRecharge> queryActivityRechargeList(ActivityRecharge activityRecharge);

    void saveActivityRecharge(ActivityRecharge activityRecharge);

    void updateActivityRecharge(ActivityRecharge activityRecharge);

    void deleteActivityRecharge(ActivityRecharge activityRecharge);

    /**
     * 一次删除所有的充值活动
     * @param userId
     */
    void delByUserId(Integer userId);

    List<ActivityRecharge> queryActivityRechargePage(Map<String, Object> map);

    List<ActivityRecharge> queryActivityNoRechargePage(Map<String, Object> map);

    Integer queryActivityRechargePageCount(Map<String, Object> map);

    Integer queryActivityNoRechargePageCount(Map<String, Object> map);

    /**
     * 获取充值赠送金额
     * @param merchantCode
     * @param storeId
     * @param rechargeMoney
     * @return
     */
    double getRechargeReturnAmt(String merchantCode, String storeId, double rechargeMoney);

    /**
     * 查询进行中的活动
     * @param activityRecharge
     * @return
     */
    List<ActivityRecharge> queryUsableActivityRechageList(ActivityRecharge activityRecharge);
}

